name = 'DBUtils'

version = (0, 9, 1)

docs = [
	{'name': "User's Guide", 'file': 'UsersGuide.html'},
]

status = 'beta'

requiredPyVersion = (2, 2, 0)

synopsis = """DBUtils provides database related support classes and functions to Webware. There is plenty of useful reusable code here."""

WebKitConfig = {
	'examplePages': ['DBUtilsExample']
}